﻿using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.ComplexEventProcessing.Adapters;
using Microsoft.ComplexEventProcessing;
using System.Diagnostics;
using System.Threading;

namespace StreamInsight.Samples.InputAdapters.DataSimulator
{
    public class SimulatedDataIntervalInput<TPayload> : TypedIntervalInputAdapter<TPayload>
    {
        /// <summary>
        /// The configuration information passed into the constructor
        /// </summary>
        private SimulatedDataInputConfig _config;

        /// <summary>
        /// Initialize the point input adapter based on the payload type and the 
        /// input configuration.
        /// </summary>
        /// <param name="config"></param>
        public SimulatedDataIntervalInput(SimulatedDataInputConfig config)
        {
            this._config = config;
        }

        public override void Resume()
        {
            ProduceEvents();
        }

        public override void Start()
        {
            ProduceEvents();
        }

        /// <summary>
        /// This is the primary method for the input adapter.  This method is invoked by the CEP engine
        /// when it is ready to receive events.  The method is responsible for tracking adapter state (i.e
        /// stopping, active, etc) and responding accordingly.
        /// </summary>
        private void ProduceEvents()
        {
            IntervalEvent<TPayload> currEvent =
                default(IntervalEvent<TPayload>);
            EnqueueOperationResult result = EnqueueOperationResult.Full;
            Random rand = new Random();

            while (true)
            {
                if (AdapterState.Stopping == AdapterState)
                {
                    // Signal that we are stopped and exit the method
                    Stopped();
                    return;
                }

                // Create a new CEP event, bound with the current timestamp and
                // a randomized payload object
                currEvent = CreateInsertEvent();
                if (null == currEvent)
                {
                    continue;
                }

                currEvent.StartTime = DateTime.Now;
                currEvent.EndTime = currEvent.StartTime + TimeSpan.FromMilliseconds(_config.EventInterval);

                // Using Activator.CreateInstance as we can't add a where TPayload : new() 
                // constraint (would have to modify the base class to add the constraint)
                currEvent.Payload = (TPayload)Activator.CreateInstance(typeof(TPayload));

                if (currEvent.Payload is IRandomInit)
                    (currEvent.Payload as IRandomInit).Init();

                // Enqueue the event and check for success
                result = Enqueue(ref currEvent);
                if (EnqueueOperationResult.Full == result)
                {
                    ReleaseEvent(ref currEvent);
                    Ready();
                    return;
                }
                Thread.Sleep(_config.EventInterval * 2);
            }
        }
    }
}
