﻿namespace StreamInsight.Samples.InputAdapters.Sql
{
    using System;
    using System.IO;
    using StreamInsight.Samples.EventTypes;
    using Microsoft.ComplexEventProcessing;
    using Microsoft.ComplexEventProcessing.Adapters;

    /// <summary>
    /// Sql input configuration structure
    /// </summary>
    public struct SqlInputConfig
    {
        /// <summary>
        /// Gets or sets the Sql Server connection string.
        /// </summary>
        public string ConnectionString { get; set; }

        /// <summary>
        /// Gets or sets the CTI frequency.
        /// </summary>
        public int CtiFrequency { get; set; }
    }

    /// <summary>
    /// Factory class for Sql Typed Input Adapter
    /// </summary>
    public class SqlInputFactory : ITypedInputAdapterFactory<SqlInputConfig>
    {
        /// <summary>
        /// Create a typed input adapter factory. TPayload is a generic - the
        /// actual payload type is provided to the constructor by the
        /// application driver code during query binding, along with the event 
        /// shape
        /// </summary>
        /// <typeparam name="TPayload">Payload type of the input adapter.</typeparam>
        /// <param name="configinfo"></param>
        /// <param name="eventshape"></param>
        /// <returns>An instance of an input adapter.</returns>
        public InputAdapterBase Create<TPayload>(SqlInputConfig configinfo, EventShape eventshape)
        {
            InputAdapterBase adapter = default(InputAdapterBase);

            // Choose the right adapter from the factory based on event shape.
            if (EventShape.Point == eventshape)
            {
                adapter = new SqlTypedPointInput(configinfo);
            }

            return adapter;
        }

        public void Dispose()
        {
        }
    }
}
