﻿namespace StreamInsight.Samples.InputAdapters.TextFile
{
    using System;
    using System.Globalization;
    using System.Xml.Serialization;
    using System.Collections.Generic;
    using Microsoft.ComplexEventProcessing;
    using Microsoft.ComplexEventProcessing.Adapters;

    /// <summary>
    /// Configuration structure for the TextFileInputAdapter.
    /// </summary>
    public struct TextFileInputConfig
    {
        /// <summary>
        /// Filename to read from.
        /// </summary>
        public string InputFileName { get; set; }

        /// <summary>
        /// Character between values in a line.
        /// </summary>
        public char Delimiter { get; set; }

        /// <summary>
        /// Frequency (event count) of CTIs to be sent by the adapter.
        /// </summary>
        public int CTIfrequency { get; set; }

        /// <summary>
        /// Input file culture. Important for reading timestamps correctly.
        /// </summary>
        public string CultureName { get; set; }

        /// <summary>
        /// Order of the values w.r.t. the event type. For each read line in
        /// the CSV file, the type's fields will be assigned in the order they
        /// appear in the list.
        /// </summary>
        public List<string> InputFieldOrders { get; set; }
    }

    public class TextFileInputFactory : IInputAdapterFactory<TextFileInputConfig>
    {
        public InputAdapterBase Create(TextFileInputConfig configInfo, EventShape eventShape, CepEventType cepEventType)
        {
            InputAdapterBase adapter = default(InputAdapterBase);

            if (eventShape == EventShape.Point)
            {
                adapter = new TextFilePointInput(configInfo, cepEventType);
            }
            else if (eventShape == EventShape.Interval)
            {
                adapter = new TextFileIntervalInput(configInfo, cepEventType);
            }
            else if (eventShape == EventShape.Edge)
            {
                adapter = new TextFileEdgeInput(configInfo, cepEventType);
            }
            else
            {
                throw new ArgumentException(
                    string.Format(CultureInfo.InvariantCulture,
                    "TextFileInputFactory cannot instantiate adapter with event shape {0}", eventShape.ToString()));
            }

            return adapter;
        }

        public void Dispose()
        {
        }
    }
}
