﻿namespace StreamInsight.Samples.Observable
{
    using System;
    using System.IO;
    using System.Threading;
    using Microsoft.ComplexEventProcessing.Adapters.Observable;

    /// <summary>
    /// Text file writer, implemented as IObserver. It can be used as event 
    /// sink in the Observable development model.
    /// </summary>
    public class MyTextFileWriterObserver : IObserver<EventTypeCount>
    {
        private StreamWriter _writer;
        private int _eventCounter;
        private ManualResetEvent _observerStopSignal;

        /// <summary>
        /// Initializes a new instance of the MyTextFileWriterObserver class.
        /// </summary>
        /// <param name="fileName">File name to write to. If empty, then 
        /// events are dumped onto the console window.</param>
        /// <param name="observerStopSignal">event handle to signal 
        /// end-of-stream to the main thread.</param>
        public MyTextFileWriterObserver(string fileName, ManualResetEvent observerStopSignal)
        {
            if (fileName.Length == 0)
            {
                _writer = new StreamWriter(Console.OpenStandardOutput());
            }
            else
            {
                _writer = new StreamWriter(fileName, false);
            }

            _eventCounter = 0;
            _observerStopSignal = observerStopSignal;
        }

        public void OnCompleted()
        {
            _writer.Flush();
            _writer.Close();

            // Signal to the main thread that we are done here.
            _observerStopSignal.Set();
        }

        public void OnError(Exception error)
        {
            throw error;
        }

        public void OnNext(EventTypeCount value)
        {
            ++_eventCounter;

            _writer.Write(value.Time + "\t");
            _writer.Write(value.EventType + "\t");
            _writer.Write(value.EventCount + "\n");
        }
    }
}
