﻿namespace StreamInsight.Samples.OutputAdapters.Sql
{
    using System;
    using Microsoft.ComplexEventProcessing;
    using Microsoft.ComplexEventProcessing.Adapters;

    // Configuration info for the sink table. You can add as many output database
    // specific attributes that you want here and add relevant code for processing
    // these in the adapter's constructor. The main requirement is that this structure
    // should be XMLSerializable.
    public struct SqlOutputConfig
    {
        /// <summary>
        /// Gets or sets the SQL connection string.
        /// </summary>
        public string ConnectionString { get; set; }

        /// <summary>
        /// Gets or sets the adapter stop signal. The adapter stop signal acts
        /// as a semaphore to indicate adapter stop to main query driver 
        /// routine, so that the query can be stopped
        /// </summary>
        public string AdapterStopSignal { get; set; }
    }

    public class SqlOutputFactory : ITypedOutputAdapterFactory<SqlOutputConfig>
    {
        #region public methods
        public OutputAdapterBase Create<TPayload>(SqlOutputConfig configinfo, EventShape eventshape)
        {
            OutputAdapterBase adapter = default(OutputAdapterBase);

            // only point is supported for now, expand this check when other 
            // types are supported
            if (EventShape.Point == eventshape)
            {
                adapter = new SqlTypedPointOutput(configinfo);
            }

            return adapter;
        }

        // Default dispose from base class
        public void Dispose()
        {
        }
        #endregion
    }
}
