﻿namespace StreamInsight.Samples.OutputAdapters.TextFile
{
    using System.Xml.Serialization;
    using Microsoft.ComplexEventProcessing;
    using Microsoft.ComplexEventProcessing.Adapters;

    public struct TextFileOutputConfig
    {
        public string OutputFileName { get; set; }

        public char Delimiter { get; set; }

        /// <summary>
        /// Gets or sets a asgnal handler to synchronize between adapter and 
        /// main application thread.
        /// </summary>
        public string AdapterStopSignal { get; set; }
    }

    public class TextFileOutputFactory : IOutputAdapterFactory<TextFileOutputConfig>
    {
        public OutputAdapterBase Create(TextFileOutputConfig configInfo, EventShape eventShape, CepEventType cepEventType)
        {
            OutputAdapterBase adapter = default(OutputAdapterBase);

            switch (eventShape)
            {
                case EventShape.Point:
                    adapter = new TextFilePointOutput(configInfo, cepEventType);
                    break;
                case EventShape.Interval:
                    adapter = new TextFileIntervalOutput(configInfo, cepEventType);
                    break;
                case EventShape.Edge:
                    adapter = new TextFileEdgeOutput(configInfo, cepEventType);
                    break;
                default:
                    break;
            }

            return adapter;
        }

        public void Dispose()
        {
        }
    }
}
