﻿namespace StreamInsight.Samples.PatternDetector
{
    using System;
    using Microsoft.ComplexEventProcessing;
    using Microsoft.ComplexEventProcessing.Linq;
    using StreamInsight.Samples.Extensibility.PatternUDO;
    using StreamInsight.Samples.OutputAdapters.Trace;

    class PatternDetector
    {
        static void Main(string[] args)
        {
            // Use an array as observable query input.
            // The pattern matcher in this sample looks for an equal number of
            // subsequent downticks and upticks, sub-patterns included. With
            // the event sequence below, this pattern is triggered at minutes
            // 6, 10, 11, 16, 17, 18, 19.
            StockTick[] mylist = new StockTick[]
            {
                new StockTick("3/24/2009 4:05:00 PM", "XYZ", 300, -5),
                new StockTick("3/24/2009 4:06:00 PM", "XYZ", 303,  3),
                new StockTick("3/24/2009 4:07:00 PM", "XYZ", 297, -6),
                new StockTick("3/24/2009 4:08:00 PM", "XYZ", 289, -8),
                new StockTick("3/24/2009 4:09:00 PM", "XYZ", 288, -1),
                new StockTick("3/24/2009 4:10:00 PM", "XYZ", 291,  3),
                new StockTick("3/24/2009 4:11:00 PM", "XYZ", 295,  4),
                new StockTick("3/24/2009 4:12:00 PM", "XYZ", 293, -2),
                new StockTick("3/24/2009 4:13:00 PM", "XYZ", 289, -4),
                new StockTick("3/24/2009 4:14:00 PM", "XYZ", 286, -3),
                new StockTick("3/24/2009 4:15:00 PM", "XYZ", 279, -7),
                new StockTick("3/24/2009 4:16:00 PM", "XYZ", 283,  4),
                new StockTick("3/24/2009 4:17:00 PM", "XYZ", 288,  5),
                new StockTick("3/24/2009 4:18:00 PM", "XYZ", 295,  7),
                new StockTick("3/24/2009 4:19:00 PM", "XYZ", 298,  3),
                new StockTick("3/24/2009 4:20:00 PM", "XYZ", 304,  6)
            };

            AdvanceTimeSettings ats = new AdvanceTimeSettings(1, TimeSpan.FromSeconds(0), AdvanceTimePolicy.Drop);

            // use the implicit PointEvent mapping and just specify the timestamp source
            var inputStream = mylist.ToObservable().ToCepStream(e => e.ts, ats);

            // For the input stock, report the pattern matches over the last hour, and update
            // the result every hour. Each pattern match is output as an event with a counter
            // as payload. By definition of the pattern transition network, this counter will
            // always be zero for a match. Here, the register of the transition network will
            // also be the query output type, but the payload can be augmented to include more
            // information if desired.

            var result = from w in inputStream.TumblingWindow(TimeSpan.FromHours(1))
                         select w.ATNCore<StockTick, ATNRegisterType>(typeof(ATN_EqualDownticksUpticks).AssemblyQualifiedName.ToString());

            var traceOutputConf = new TraceConfig { TraceType = TraceTypeValue.Console, TraceName = "consoleout", DisplayCtiEvents = false };

            Query query = result.ToQuery(typeof(TraceOutputFactory), traceOutputConf, EventShape.Point, StreamEventOrder.ChainOrdered);

            query.Start();

            Console.WriteLine("Stop query with enter");
            Console.ReadLine();

            query.Stop();
        }
    }
}
