﻿namespace StreamInsight.Samples.Extensibility.PatternUDO
{
    using System.Collections.Generic;
    using Microsoft.ComplexEventProcessing;
    using Microsoft.ComplexEventProcessing.Linq;

    public interface IATNDescriptorGenerator<TInput, TRegister>
    {
        ATNDescriptor<TInput, TRegister> GetATNDescriptor();
    }

    public class ATNDescriptor<TInput, TRegister>
    {
        public delegate bool TransitionDelegate(List<TInput> inputEvents, TRegister oldRegister, out TRegister newRegister);
        private Dictionary<int, Dictionary<int, TransitionDelegate>> transitionInfo = new Dictionary<int, Dictionary<int, TransitionDelegate>>();

        private int _startState;
        public int StartState
        {
            get { return _startState; }
            set { _startState = value; }
        }

        private List<int> _finalStates = new List<int>();

        public void AddFinalState(int state)
        {
            _finalStates.Add(state);
        }

        private TRegister defaultRegister;
        public TRegister DefaultRegister
        {
            get
            {
                return defaultRegister;
            }

            set
            {
                defaultRegister = value;
            }
        }

        public void AddArc(int fromState, int toState, TransitionDelegate func)
        {
            if (!transitionInfo.ContainsKey(fromState))
            {
                transitionInfo.Add(fromState, new Dictionary<int, TransitionDelegate>());
            }
            if (!transitionInfo[fromState].ContainsKey(toState))
            {
                transitionInfo[fromState].Add(toState, func);
            }
            else
            {
                transitionInfo[fromState][toState] = func;
            }
        }


        internal bool IsFinalState(int state)
        {
            return _finalStates.Contains(state);
        }


        internal List<int> GetToStates(int _fromState)
        {
            List<int> result = new List<int>();
            Dictionary<int, TransitionDelegate> tmp;
            if (transitionInfo.TryGetValue(_fromState, out tmp))
            {
                foreach (KeyValuePair<int, TransitionDelegate> kvp in tmp)
                {
                    result.Add(kvp.Key);
                }
            }
            return result;
        }

        internal bool ApplyTransition(EventSet<TInput> inputEvents, int fromState, int toState, TRegister oldRegister, out TRegister newRegister)
        {
            TransitionDelegate arc;
            if (transitionInfo.ContainsKey(fromState) && transitionInfo[fromState].TryGetValue(toState, out arc))
            {
                // extract payloads from events
                List<TInput> list = new List<TInput>();
                foreach (IntervalEvent<TInput> e in inputEvents.EventList)
                {
                    list.Add(e.Payload);
                }
                return arc(list, oldRegister, out newRegister);
            }
            newRegister = default(TRegister);
            return false;
        }

    };

    static public class ATNUDOExtensionMethods
    {
        [CepUserDefinedOperator(typeof(ATNCore<,>))]
        public static TRegister ATNCore<TInput, TRegister>(this CepWindow<TInput> window, string typeName)
        {
            throw CepUtility.DoNotCall();
        }

    }

}
