﻿namespace StreamInsight.Samples.Extensibility.TimeWeightedAverage
{
    using System;
    using System.Collections.Generic;
    using System.Linq.Expressions;
    using Microsoft.ComplexEventProcessing;
    using Microsoft.ComplexEventProcessing.Extensibility;
    using Microsoft.ComplexEventProcessing.Linq;

    public class TwaConfig
    {
        public double weight { get; set; }
    }

    public class TimeWeightedAverage : CepTimeSensitiveAggregate<double, double>
    {
        TwaConfig _config;

        public TimeWeightedAverage(TwaConfig config)
        {
            _config = config;
        }

        public override double GenerateOutput(IEnumerable<IntervalEvent<double>> events, WindowDescriptor windowDescriptor)
        {
            double avg = 0;
            foreach (IntervalEvent<double> intervalEvent in events)
            {
                avg += intervalEvent.Payload * (intervalEvent.EndTime - intervalEvent.StartTime).Ticks;
            }
            return avg / (windowDescriptor.EndTime - windowDescriptor.StartTime).Ticks * _config.weight;
        }
    }

    /// <summary>
    /// This is the extension method for LINQ, to make the UDA usable for query writers.
    /// </summary>
    static public class UDAExtensionMethods
    {
        [CepUserDefinedAggregate(typeof(TimeWeightedAverage))]
        public static double twa<T>(this CepWindow<T> window, Expression<Func<T, double>> map, TwaConfig config)
        {
            throw CepUtility.DoNotCall();
        }
    }
}

