﻿using System;
using System.ServiceModel;
using Microsoft.ComplexEventProcessing;
using Microsoft.ComplexEventProcessing.Linq;
using Microsoft.ComplexEventProcessing.ManagementService;
using StreamInsight.Samples.Adapters.DataGenerator;
using StreamInsight.Samples.Adapters.OutputTracer;

namespace StreamInsightSimple
{
    class Program
    {
        static void Main(string[] args)
        {
            using (Server server = Server.Connect(new System.ServiceModel.EndpointAddress(@"http://localhost/MyStreamInsightServer")))
            {
                try
                {
                    Application myApp = server.Applications["DeviceReadings"];

                    // Configuration of the tracer output adapter.
                    var tracerConfig = new TracerConfig()
                    {
                        DisplayCtiEvents = false,
                        SingleLine = true,
                        TraceName = "Consumer",
                        TracerKind = TracerKind.Console
                    };

                    // Create an input stream directly from the adapter,
                    // requesting point events from the simulator.
                    //var inputstream = CepStream<GeneratedEvent>.Create("input", typeof(GeneratorFactory), generatorConfig, EventShape.Point);
                    var inputstream = CepStream<GeneratedEvent>.Create(
                        new Uri("cep:/Server/Application/DeviceReadings/Query/PassThru"),
                        EventShape.Point);

                    // Simple pass through query.  Grab the input values, pass to the 
                    // output adapter
                    var consumer = from e in inputstream select e;

                    // Turn this logic into a query, outputting to the tracer output adapter.
                    var query = consumer.ToQuery(
                        myApp,
                        "Consumer",
                        string.Empty,
                        typeof(TracerFactory),
                        tracerConfig,
                        EventShape.Point,
                        StreamEventOrder.FullyOrdered);

                    // Start the query now.
                    query.Start();

                    // Wait for keystroke to end.
                    Console.ReadLine();

                    // Stop both queries.
                    query.Stop();

                    Console.WriteLine("Query stopped. Press enter to exit application.");
                    Console.ReadLine();

                }
                catch (Exception e)
                {
                    Console.WriteLine(e);
                    Console.ReadLine();
                }
            }
        }
    }
}
