﻿using System;
using System.ServiceModel;
using Microsoft.ComplexEventProcessing;
using Microsoft.ComplexEventProcessing.Linq;
using Microsoft.ComplexEventProcessing.ManagementService;
using StreamInsight.Samples.Adapters.DataGenerator;
using StreamInsight.Samples.Adapters.OutputTracer;

namespace StreamInsightSimple
{
    class Program
    {
        static void Main(string[] args)
        {
            // Creating an embedded server.
            //
            // NOTE: replace "Default" with the instance name you provided
            // during StreamInsight setup.
            using (Server server = Server.Create("Default"))
            {
                // Comment out if you want to create a service host and expose
                // the server's endpoint:

                //ServiceHost host = new ServiceHost(server.CreateManagementService());

                //host.AddServiceEndpoint(
                //    typeof(IManagementService),
                //    new WSHttpBinding(SecurityMode.Message),
                //    "http://localhost/MyStreamInsightServer");

                // To enable remote connection / debugging, you also need to uncomment the
                // lines "host.Open()" and "host.Close()".
                // In addition, the URI needs to be provisioned for the
                // account that runs this process (unless Administrator). To do this, open
                // an admin shell and execute the following command, using the respective
                // user credentials:
                // netsh http add urlacl url=http://+:80/MyStreamInsightServer user=<domain\username>

                //host.Open();

                // Configuration of the data generator input adapter.
                var generatorConfig = new GeneratorConfig()
                {
                    CtiFrequency = 1,
                    EventInterval = 500,
                    EventIntervalVariance = 450,
                    DeviceCount = 5,
                    MaxValue = 100
                };

                // Configuration of the tracer output adapter.
                var tracerConfig = new TracerConfig()
                {
                    DisplayCtiEvents = false,
                    SingleLine = true,
                    TraceName = "Passthru",
                    TracerKind = TracerKind.Console
                };

                try
                {
                    var myApp = server.CreateApplication("DeviceReadings");

                    // Create an input stream directly from the adapter,
                    // requesting point events from the simulator.
                    var inputstream = CepStream<GeneratedEvent>.Create("input", typeof(GeneratorFactory), generatorConfig, EventShape.Point);


                    // Simple pass through query.  Grab the input values, pass to the 
                    // output adapter
                    var passthru = from e in inputstream select e;

                    // Turn this logic into a query, outputting to the tracer output adapter.
                    var query = passthru.ToQuery(
                        myApp,
                        "PassThru",
                        string.Empty,
                        typeof(TracerFactory),
                        tracerConfig,
                        EventShape.Point,
                        StreamEventOrder.FullyOrdered);

                    // Start the query now.
                    query.Start();

                    // Wait for keystroke to end.
                    Console.ReadLine();

                    // Stop both queries.
                    query.Stop();

                    Console.WriteLine("Query stopped. Press enter to exit application.");
                    Console.ReadLine();

                    //host.Close();
                }
                catch (Exception e)
                {
                    Console.WriteLine(e);
                    Console.ReadLine();
                }
            }
        }
    }
}
